@@ -1,4 +1,4 @@
-paragraph_style <- function(style_data, row_offset, objectId) {
+paragraph_style <- function(style_data, row_offset, has_text, objectId) {
   part_dim <- dim(style_data[[1]][["data"]])
   i <- seq_len(part_dim[1]) # i is 1-indexed and relative to table part
   i_gs <- i - 1 + row_offset # Slide table rows are 0-indexed and absolute
@@ -20,16 +20,20 @@ paragraph_style <- function(style_data, row_offset, objectId) {
   # iterate over columns, assuming text alignment is usually consistent column-wise
   for (this_i in i) {
     for (this_j in j) {
-      add(reqs) <- UpdateParagraphStyleRequest(
-        objectId = objectId,
-        cellLocation = TableCellLocation(rowIndex = i_gs[this_i], j_gs[this_j]),
-        style = ParagraphStyle(
-          direction = "LEFT_TO_RIGHT",
-          alignment = map[ta[this_i, this_j]]
-        ),
-        textRange = Range(type = "ALL"),
-        fields = "alignment,direction"
-      )
+      if (!isTRUE(has_text[this_i, this_j])) {
+        next
+      } else {
+        add(reqs) <- UpdateParagraphStyleRequest(
+          objectId = objectId,
+          cellLocation = TableCellLocation(rowIndex = i_gs[this_i], j_gs[this_j]),
+          style = ParagraphStyle(
+            direction = "LEFT_TO_RIGHT",
+            alignment = unname(map[ta[this_i, this_j]])
+          ),
+          textRange = Range(type = "ALL"),
+          fields = "alignment,direction"
+        )
+      }
     }
   }
   reqs
